searchData={"content_type":"text/markdown","items":[{"doc":"`SwissSchema` is a query toolkit for Ecto schemas. It makes it easy to manipulate data using Ecto schemas by implementing relevant Ecto.Repo [Query API](https://hexdocs.pm/ecto/Ecto.Repo.html#query-api) and [Schema API](https://hexdocs.pm/ecto/Ecto.Repo.html#schema-api) functions, pre-configured to work specifically with the given Ecto schema.","ref":"SwissSchema.html","title":"SwissSchema","type":"behaviour"},{"doc":"Add `swiss_schema` as a dependency in `mix.exs`:\n\n    def deps do\n    [\n      # ...\n      {:swiss_schema, \"~> 0.4\"}\n    ]\n    end\n\nThen, `use SwissSchema` in your Ecto schemas:\n\n    # lib/my_app/accounts/user.ex\n\n    defmodule MyApp.Accounts.User do\n      use Ecto.Schema\n      use SwissSchema, repo: MyApp.Repo\n    end\n\nThat's it, you should be good to go.","ref":"SwissSchema.html#module-setup","title":"Setup - SwissSchema","type":"behaviour"},{"doc":"After setting up SwissSchema in your Ecto schema, there isn't much else to do. Just use the available functions now available in your own schema module:\n\n    iex> alias MyApp.Accounts.User\n\n    iex> User.all()\n    []\n\n    iex> User.create(%{name: \"John Smith\", email: \"john@smiths.net\"})\n    {:ok, %User%{name: \"John Smith\", ...}}\n\n    iex> User.all()\n    [%User%{name: \"John Smith\", ...}]\n\n`SwissSchema` functions tries to mimic the Ecto.Repo's Query and Repo APIs by acting as a thin, pre-configured interface for Ecto.Repo callbacks.\n\n> ##","ref":"SwissSchema.html#module-usage","title":"Usage - SwissSchema","type":"behaviour"},{"doc":">\n> To keep examples short and simple, we use the example module from the previous section, `MyApp.Accounts.User`, in the functions documentation. So, when reading the docs for SwissSchema functions, assume the following alias was previously set up:\n>\n>     alias MyApp.Accounts.User\n>\n> So, the module `MyApp.Accounts.User` itself will be referred to just as `User`.","ref":"SwissSchema.html#module-note-info","title":"Note {: .info} - SwissSchema","type":"behaviour"},{"doc":"","ref":"SwissSchema.html#c:aggregate/2","title":"SwissSchema.aggregate/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:aggregate/3","title":"SwissSchema.aggregate/3","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:all/1","title":"SwissSchema.all/1","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:create/2","title":"SwissSchema.create/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:create!/2","title":"SwissSchema.create!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:delete/2","title":"SwissSchema.delete/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:delete!/2","title":"SwissSchema.delete!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:delete_all/1","title":"SwissSchema.delete_all/1","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:get/2","title":"SwissSchema.get/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:get!/2","title":"SwissSchema.get!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:get_by/2","title":"SwissSchema.get_by/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:get_by!/2","title":"SwissSchema.get_by!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:insert/2","title":"SwissSchema.insert/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:insert!/2","title":"SwissSchema.insert!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:insert_all/2","title":"SwissSchema.insert_all/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:insert_or_update/2","title":"SwissSchema.insert_or_update/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:insert_or_update!/2","title":"SwissSchema.insert_or_update!/2","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:stream/1","title":"SwissSchema.stream/1","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:update/3","title":"SwissSchema.update/3","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:update!/3","title":"SwissSchema.update!/3","type":"callback"},{"doc":"","ref":"SwissSchema.html#c:update_all/2","title":"SwissSchema.update_all/2","type":"callback"}]}